@@ -18,7 +18,7 @@ sub acceptance {
   Test::More::plan(skip_all => $@)                            unless eval "require $schema_class;1";
 
   my $test = sub { +{file => $_[0], group_description => $_[1], test_description => $_[2]} };
-  my $ua   = _acceptance_ua($schema_class);
+  my $ua   = _acceptance_ua();
 
   $acceptance_params{todo_tests} = [map { $test->(@$_) } @{$acceptance_params{todo_tests}}]
     if $acceptance_params{todo_tests};
@@ -30,7 +30,7 @@ sub acceptance {
     %acceptance_params,
     validate_data => sub {
       my ($schema_p, $data_p) = map { Mojo::JSON::Pointer->new(shift @_) } qw(schema data);
-      my ($schema_d, $data_d) = map { clone($_->data) } $schema_p, $data_p;
+      my ($schema_d, $data_d) = map { decode_json(encode_json($_->data)) } $schema_p, $data_p;
 
       my $schema = $schema_class->new($schema_d, ua => $ua);
       return 0 if @{$schema->errors};
@@ -47,10 +47,6 @@ sub acceptance {
   );
 }
 
-sub clone {
-  return decode_json(encode_json($_[0]));
-}
-
 sub edj {
   return Mojo::JSON::decode_json(Mojo::JSON::encode_json(@_));
 }
@@ -117,7 +113,6 @@ sub import {
 }
 
 sub _acceptance_ua {
-  my $schema_class = shift;
   require Mojo::UserAgent;
   require Mojolicious;
   my $ua  = Mojo::UserAgent->new;
@@ -134,33 +129,6 @@ sub _acceptance_ua {
     }
   ) for qw(prepare start);
 
-  my $app_base_url = $ua->get('/')->req->url->to_abs->to_string;
-  $app_base_url =~ s!/$!!;
-
-  my $orig_load_schema = $schema_class->can('_load_schema');
-  monkey_patch $schema_class => _load_schema => sub {
-    my ($self, $url) = @_;
-    my $cached;
-    return $cached, $url if $cached = $self->_store($url);
-    $url =~ s!^https?://localhost:1234!$app_base_url!;
-    return $self->$orig_load_schema($url);
-  };
-
-  #my $orig_resolve_ref = $schema_class->can('_resolve_ref');
-  #monkey_patch $schema_class => _resolve_ref => sub {
-  #  my ($self, $ref_url, $base_url, $schema) = @_;
-  #  $ref_url  =~ s!^https?://localhost:1234!$app_base_url!;
-  #  $base_url =~ s!^https?://localhost:1234!$app_base_url!;
-  #  $self->$orig_resolve_ref($ref_url, $base_url, $schema);
-  #};
-
-  #my $orig_store       = $schema_class->can('_store');
-  #monkey_patch $schema_class => _store => sub {
-  #  my ($self, $id, $schema) = @_;
-  #  $id =~ s!^https?://localhost:1234!$app_base_url!;
-  #  $self->$orig_store($id, $schema);
-  #};
-
   return $ua;
 }
 
